unit penstylecombo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls;

type
  Tpenstylecombo = class(TCustomComboBox)
  private
    function GetSelection: TPenStyle;
    procedure SetSelection(Value: TPenStyle);
  protected
    procedure SetStyle(Value: TComboBoxStyle); override;
    procedure DrawItem(Index: Integer; Rect: TRect;
      State: TOwnerDrawState); override;
    procedure CreateWnd; override;
  public
    constructor Create(AOwner: TComponent); override;
    procedure SetStyleList; virtual;
    property Selection: TPenStyle read GetSelection write SetSelection;
  published
    property Color;
    property Ctl3D;
    property DragMode;
    property DragCursor;
    property DropDownCount;
    property Enabled;
    property Font;
    property ItemHeight;
    property Items;
    property MaxLength;
    property ParentColor;
    property ParentCtl3D;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property Sorted;
    property TabOrder;
    property TabStop;
    property Text;
    property Visible;
    property OnChange;
    property OnClick;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnDrawItem;
    property OnDropDown;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;
    property OnMeasureItem;
    property OnStartDrag;
  end;

procedure Register;

implementation

const
  penstyleArray: array[0..5] of string =
  ('Solid', 'Dash', 'Dot', 'DashDot', 'DashDotDot', 'Clear');

procedure Register;
begin
  RegisterComponents('Smart', [Tpenstylecombo]);
end;

function Tpenstylecombo.GetSelection: TPenStyle;
begin
  result:=TPenStyle(ItemIndex);
end;

procedure Tpenstylecombo.SetSelection(Value: TPenStyle);
var
  i: integer;
begin
  for i:=0 to 6 do
    if TPenStyle(i) = Value then
    begin
      ItemIndex :=i;
      exit;
    end;  
end;

procedure Tpenstylecombo.SetStyle(Value: TComboBoxStyle);
begin
  inherited SetStyle(csOwnerDrawFixed);
end;

procedure Tpenstylecombo.DrawItem(Index: Integer; Rect: TRect; State: TOwnerDrawState);
var
  r: TRect;
  ItemColor, c: TColor;
begin
  r.top := Rect.top + 3;
  r.bottom := Rect.bottom - 3;
  r.left := Rect.left + 3;
  r.right := r.left + 45;

  with Canvas do
  begin
    FillRect(Rect);
    pen.style:=tpenstyle(index);

    pen.color:=clBlack;
    moveto(r.Left,r.top + (r.Bottom - r.top) div 2);
    lineto(r.right,r.top + (r.Bottom - r.top) div 2);

    FrameRect(r);
  end;
  r := Rect;
  r.left := r.left + 50;

  inherited DrawItem(Index, r, State);
end;

procedure Tpenstylecombo.CreateWnd;
begin
  inherited CreateWnd;
  SetStyleList;
end;

constructor Tpenstylecombo.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  Style := csOwnerDrawFixed;
end;

procedure Tpenstylecombo.SetStyleList;
var
  c: integer;
  s: String;
begin
  if csDesigning in ComponentState then
    with items do
    begin
      clear;
      for c := 0 to High(penstyleArray) do
        Add(penstyleArray[c]);
    end;
end;


end.
